"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DynamicPrivateProjectConfigContextField = exports.DynamicPublicProjectConfigContextField = void 0;
const tslib_1 = require("tslib");
const ContextField_1 = tslib_1.__importDefault(require("./ContextField"));
const findProjectDirAndVerifyProjectSetupAsync_1 = require("./contextUtils/findProjectDirAndVerifyProjectSetupAsync");
const getProjectIdAsync_1 = require("./contextUtils/getProjectIdAsync");
const expoConfig_1 = require("../../project/expoConfig");
class DynamicPublicProjectConfigContextField extends ContextField_1.default {
    async getValueAsync({ nonInteractive, sessionManager, }) {
        const projectDir = await (0, findProjectDirAndVerifyProjectSetupAsync_1.findProjectDirAndVerifyProjectSetupAsync)();
        return async (options) => {
            const expBefore = (0, expoConfig_1.getPublicExpoConfig)(projectDir, options);
            const projectId = await (0, getProjectIdAsync_1.getProjectIdAsync)(sessionManager, expBefore, {
                nonInteractive,
                env: options?.env,
            });
            const exp = (0, expoConfig_1.getPublicExpoConfig)(projectDir, options);
            return {
                exp,
                projectDir,
                projectId,
            };
        };
    }
}
exports.DynamicPublicProjectConfigContextField = DynamicPublicProjectConfigContextField;
class DynamicPrivateProjectConfigContextField extends ContextField_1.default {
    async getValueAsync({ nonInteractive, sessionManager, }) {
        const projectDir = await (0, findProjectDirAndVerifyProjectSetupAsync_1.findProjectDirAndVerifyProjectSetupAsync)();
        return async (options) => {
            const expBefore = (0, expoConfig_1.getPrivateExpoConfig)(projectDir, options);
            const projectId = await (0, getProjectIdAsync_1.getProjectIdAsync)(sessionManager, expBefore, {
                nonInteractive,
                env: options?.env,
            });
            const exp = (0, expoConfig_1.getPrivateExpoConfig)(projectDir, options);
            return {
                exp,
                projectDir,
                projectId,
            };
        };
    }
}
exports.DynamicPrivateProjectConfigContextField = DynamicPrivateProjectConfigContextField;
