"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OptionalPrivateProjectConfigContextField = void 0;
const tslib_1 = require("tslib");
const errors_1 = require("@expo/eas-json/build/errors");
const ContextField_1 = tslib_1.__importDefault(require("./ContextField"));
const findProjectDirAndVerifyProjectSetupAsync_1 = require("./contextUtils/findProjectDirAndVerifyProjectSetupAsync");
const getProjectIdAsync_1 = require("./contextUtils/getProjectIdAsync");
const expoConfig_1 = require("../../project/expoConfig");
class OptionalPrivateProjectConfigContextField extends ContextField_1.default {
    async getValueAsync({ nonInteractive, sessionManager }) {
        let projectDir;
        try {
            projectDir = await (0, findProjectDirAndVerifyProjectSetupAsync_1.findProjectDirAndVerifyProjectSetupAsync)();
            if (!projectDir) {
                return undefined;
            }
        }
        catch (e) {
            if (e instanceof errors_1.InvalidEasJsonError) {
                throw e;
            }
            return undefined;
        }
        const expBefore = (0, expoConfig_1.getPrivateExpoConfig)(projectDir);
        const projectId = await (0, getProjectIdAsync_1.getProjectIdAsync)(sessionManager, expBefore, {
            nonInteractive,
        });
        const exp = (0, expoConfig_1.getPrivateExpoConfig)(projectDir);
        return {
            exp,
            projectDir,
            projectId,
        };
    }
}
exports.OptionalPrivateProjectConfigContextField = OptionalPrivateProjectConfigContextField;
