"use strict";
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const EasCommand_1 = tslib_1.__importDefault(require("../../commandUtils/EasCommand"));
const WebhookQuery_1 = require("../../graphql/queries/WebhookQuery");
const log_1 = tslib_1.__importDefault(require("../../log"));
const ora_1 = require("../../ora");
const formatWebhook_1 = require("../../webhooks/formatWebhook");
class WebhookView extends EasCommand_1.default {
    async runAsync() {
        const { args: { ID: webhookId }, } = await this.parse(_a);
        const { loggedIn: { graphqlClient }, } = await this.getContextAsync(_a, { nonInteractive: true });
        const spinner = (0, ora_1.ora)(`Fetching the webhook details for ID ${webhookId}`).start();
        try {
            const webhook = await WebhookQuery_1.WebhookQuery.byIdAsync(graphqlClient, webhookId);
            spinner.succeed(`Found the webhook details`);
            log_1.default.log(`\n${(0, formatWebhook_1.formatWebhook)(webhook)}`);
        }
        catch (err) {
            spinner.fail(`Couldn't find the webhook with ID ${webhookId}`);
            throw err;
        }
    }
}
_a = WebhookView;
WebhookView.description = 'view a webhook';
WebhookView.args = [
    {
        name: 'ID',
        required: true,
        description: 'ID of the webhook to view',
    },
];
WebhookView.contextDefinition = {
    ..._a.ContextOptions.LoggedIn,
};
exports.default = WebhookView;
