"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RemoveFcm = void 0;
const tslib_1 = require("tslib");
const log_1 = tslib_1.__importDefault(require("../../../log"));
const prompts_1 = require("../../../prompts");
const GraphqlClient_1 = require("../api/GraphqlClient");
class RemoveFcm {
    constructor(app) {
        this.app = app;
    }
    async runAsync(ctx) {
        if (ctx.nonInteractive) {
            throw new Error("Deleting an FCM API Key is a destructive operation. Start the CLI without the '--non-interactive' flag to delete the credentials.");
        }
        const appCredentials = await ctx.android.getAndroidAppCredentialsWithCommonFieldsAsync(ctx.graphqlClient, this.app);
        const fcm = appCredentials?.androidFcm;
        if (!fcm) {
            log_1.default.warn(`There is no valid FCM API Key defined for ${(0, GraphqlClient_1.formatProjectFullName)(this.app)}, ${this.app.androidApplicationIdentifier}`);
            return;
        }
        const confirm = await (0, prompts_1.confirmAsync)({
            message: 'Permanently delete the FCM API Key from Expo servers?',
            initial: false,
        });
        if (!confirm) {
            return;
        }
        await ctx.android.deleteFcmAsync(ctx.graphqlClient, fcm);
        log_1.default.succeed('FCM API Key removed');
    }
}
exports.RemoveFcm = RemoveFcm;
