"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RemoveProvisioningProfiles = void 0;
const tslib_1 = require("tslib");
const assert_1 = tslib_1.__importDefault(require("assert"));
const log_1 = tslib_1.__importDefault(require("../../../log"));
class RemoveProvisioningProfiles {
    constructor(apps, provisioningProfiles) {
        this.apps = apps;
        this.provisioningProfiles = provisioningProfiles;
        (0, assert_1.default)(apps.length === provisioningProfiles.length, 'apps must correspond to the provisioning profiles being removed');
    }
    async runAsync(ctx) {
        if (this.provisioningProfiles.length === 0) {
            log_1.default.log(`Skipping deletion of Provisioning Profiles`);
            return;
        }
        await ctx.ios.deleteProvisioningProfilesAsync(ctx.graphqlClient, this.provisioningProfiles.map(profile => profile.id));
        const appAndBundles = this.apps
            .map(app => `@${app.account.name}/${app.projectName} (${app.bundleIdentifier})`)
            .join(',');
        log_1.default.succeed(`Successfully removed provisioning profiles for ${appAndBundles}`);
    }
}
exports.RemoveProvisioningProfiles = RemoveProvisioningProfiles;
